#
# bluetooth.py 
# Easy API - bluetooth module.
#
# Copyright (C) 2005-2006 INdT - Instituto Nokia de Tecnologia
#
# Contact: Luciano Miguel Wolf <luciano.wolf@indt.org.br>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#

""" Bluetooth module is composed  of bluetooth's device manipulation. This
module uses LightBlue a cross-platform Python Bluetooth API which provides
simple access to Bluetooth operations (http://lightblue.sourceforge.net/).
"""
import lightblue as bluetooth

__all__ = ["finddevices", "findservices", "finddevicename", "gethostaddr", 
           "gethostclass", "socket", "advertise", "stopadvertise",
           "selectdevice", "selectservice"]

finddevicename = bluetooth.finddevicename
finddevices = bluetooth.finddevices
findservices = bluetooth.findservices
gethostaddr = bluetooth.gethostaddr
gethostclass = bluetooth.gethostclass
obex = bluetooth.obex
selectdevice = bluetooth.selectdevice
selectservice = bluetooth.selectservice
socket = bluetooth.socket
stopadvertise = bluetooth.stopadvertise